@@ -175,7 +175,7 @@ class CdnClient(AbstractClient):
 
 
     def DescribeDomains(self, request):
-        """This API is used to query the basic configuration information of CDN acceleration domain names (inside and outside mainland China), including the project ID, service status, business type, creation time, and update time, etc.
+        """This API is used to query the basic configuration information of CDN acceleration domain names (inside and outside mainland China), including the project ID, service status, service type, creation time, and update time, etc.
 
         :param request: Request instance for DescribeDomains.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeDomainsRequest`
@@ -203,7 +203,7 @@ class CdnClient(AbstractClient):
 
 
     def DescribeDomainsConfig(self, request):
-        """This API is used to query all the configuration information of CDN acceleration domain names (inside and outside mainland China).
+        """This API is used to query the complete configuration information of CDN acceleration domain names (inside and outside mainland China).
 
         :param request: Request instance for DescribeDomainsConfig.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeDomainsConfigRequest`
@@ -414,7 +414,7 @@ class CdnClient(AbstractClient):
 
     def DescribeUrlViolations(self, request):
         """This API is used to query the list of domain name URLs containing regulation-violating content scanned and detected by the CDN system, and the current status of the URLs.
-        It corresponds to the **Pornography Detection** page of the CDN Console.
+        It corresponds to the **Pornography Detection** page on the CDN Console.
 
         :param request: Request instance for DescribeUrlViolations.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeUrlViolationsRequest`
@@ -498,7 +498,7 @@ class CdnClient(AbstractClient):
 
 
     def GetDisableRecords(self, request):
-        """This API is used to query the resource blocking history and the current URL status. (This API is in beta test and not fully available yet.)
+        """This API is used to query the resource blocking history and the current URL status. (This API is in beta test and not generally available yet.)
 
         :param request: Request instance for GetDisableRecords.
         :type request: :class:`tencentcloud.cdn.v20180606.models.GetDisableRecordsRequest`
@@ -526,7 +526,7 @@ class CdnClient(AbstractClient):
 
 
     def ListTopData(self, request):
-        """This API is used to query the following sorting data by using different combinations of the Metric and Filter input parameters:
+        """This API is used to list data sorted the following ways by using different combinations of the Metric and Filter input parameters:
 
         + It sorts access URLs by total traffic and total requests, and returns the top 1,000 URLs in descending order.
         + It sorts client districts by total traffic and total requests, and returns the list of districts in descending order.
@@ -534,7 +534,7 @@ class CdnClient(AbstractClient):
         + It sorts domain names by total traffic, peak bandwidth, total requests, average hit rate, and 2XX/3XX/4XX/5XX status codes, and returns the list of domain names in descending order.
         + It sorts domain names by total origin-pull traffic, peak origin-pull bandwidth, total origin-pull requests, average origin-pull failure rate, and 2XX/3XX/4XX/5XX origin-pull status codes, and returns the list of domain names in descending order.
 
-        Note: only querying of data within the past 90 days is supported.
+        Note: only data from the last 90 days will be queried.
 
         :param request: Request instance for ListTopData.
         :type request: :class:`tencentcloud.cdn.v20180606.models.ListTopDataRequest`
@@ -679,7 +679,7 @@ class CdnClient(AbstractClient):
 
     def StopCdnDomain(self, request):
         """This API is used to suspend the acceleration service for a domain name.
-        Note: after the acceleration service has been suspended, the requests to the cache node will directly return 404. In order to avoid impact to your business, please release it before suspending the acceleration service.
+        Note: after the acceleration service has been suspended, requests to the cache node will return a 404 error. In order to avoid impact to your business, please move the domain name to another service before suspending the acceleration service.
 
         :param request: Request instance for StopCdnDomain.
         :type request: :class:`tencentcloud.cdn.v20180606.models.StopCdnDomainRequest`
@@ -707,8 +707,8 @@ class CdnClient(AbstractClient):
 
 
     def UpdateDomainConfig(self, request):
-        """This API is used to modify the configuration information of the CDN acceleration domain names.
-        Note: if you need to update complex configuration items, you must pass all the attributes of the entire object. Attributes that are not passed will use the default value. It is recommended that you call the querying API to obtain the configuration attributes first, and then you directly modify them and pass them to this API. Due to the special nature of the certificate, for HTTPS configuration, the certificate and key fields do not need to be passed.
+        """This API is used to modify the configuration of CDN acceleration domain names.
+        Note: if you need to update complex configuration items, you must pass all the attributes of the entire object. The default value will be used for attributes that are not passed. We recommend calling the querying API to obtain the configuration attributes first. You can then modify and pass the attributes to the API. The certificate and key fields do not need to be passed for HTTPS configuration.
 
         :param request: Request instance for UpdateDomainConfig.
         :type request: :class:`tencentcloud.cdn.v20180606.models.UpdateDomainConfigRequest`
@@ -736,7 +736,7 @@ class CdnClient(AbstractClient):
 
 
     def UpdatePayType(self, request):
-        """This API is used to modify the billing mode of an account. At present, the billing mode of monthly-billed accounts and sub-accounts cannot be modified.
+        """This API is used to modify the billing mode of an account. At present, the billing mode of accounts on a monthly billing cycle and sub-accounts cannot be modified.
 
         :param request: Request instance for UpdatePayType.
         :type request: :class:`tencentcloud.cdn.v20180606.models.UpdatePayTypeRequest`
